@@ -1,5 +1,5 @@
 package Git::Version::Compare;
-$Git::Version::Compare::VERSION = '1.004';
+$Git::Version::Compare::VERSION = '1.005';
 use strict;
 use warnings;
 use Exporter;
@@ -62,7 +62,7 @@ sub looks_like_git {
     return scalar $_[0] =~
         /^(?:v|git\ version\ )?                               # prefix
           [0-9]+(?:[.-](?:0[ab]?|[1-9][0-9a-z]*|[a-zA-Z]+))*  # x.y.z.*
-          (?:[.-]?rc[0-9]+)?                                  # rc
+          (?:[.-]?[a-z]+[0-9]+)?                              # rc or vendor specific suffixes
           (?:[.-](GIT|[1-9][0-9]*[.-]g[A-Fa-f0-9]+))?         # devel
           (?:\ .*)?                                           # comment
          $/x;
@@ -209,6 +209,10 @@ Given a string, returns true if it looks like a Git version number
 (and can therefore be parsed by C<Git::Version::Number>) and false
 otherwise.
 
+It accepts the version strings from all standard Git versions and from some
+non-standard Gits as well, such as GitLab's embedded Git which uses a special
+suffix like C<.gl1>.
+
 =head1 EXPORT TAGS
 
 =head2 :ops
@@ -306,7 +310,7 @@ scripts that need B<git>.
 
 =head1 COPYRIGHT
 
-Copyright 2016 Philippe Bruhat (BooK), all rights reserved.
+Copyright 2016-2023 Philippe Bruhat (BooK), all rights reserved.
 
 =head1 LICENSE
 
